about summary refs log tree commit diff homepage
path: root/lib/Core
diff options
context:
space:
mode:
authorCristian Cadar <c.cadar@imperial.ac.uk>2021-03-20 22:23:40 +0000
committerMartinNowack <2443641+MartinNowack@users.noreply.github.com>2021-04-20 11:42:23 +0100
commitabdb0b650b8fce419dc5695e037557708f374021 (patch)
tree6b4b6f2f99a5ef34cfcc8a5d082aa7e962cc17a7 /lib/Core
parente2cb581253b18b50d6526cc4a28ee7ff933a29bf (diff)
downloadklee-abdb0b650b8fce419dc5695e037557708f374021.tar.gz
Replaced the time-based delay after which the max-static-*-pct checks are performed with one expressed in terms of number of forks.
Diffstat (limited to 'lib/Core')
-rw-r--r--lib/Core/Executor.cpp14
-rw-r--r--lib/Core/Executor.h3
2 files changed, 6 insertions, 11 deletions
diff --git a/lib/Core/Executor.h b/lib/Core/Executor.h
index db8e508c..ae960731 100644
--- a/lib/Core/Executor.h
+++ b/lib/Core/Executor.h
@@ -205,9 +205,6 @@ private:
   /// Maximum time to allow for a single instruction.
   time::Span maxInstructionTime;
 
-  /// Time after which the --max-static-*-pct checks are enforced
-  time::Span maxStaticPctCheckDelay;
-
   /// Assumes ownership of the created array objects
   ArrayCache arrayCache;
diff --git a/lib/Core/Executor.cpp b/lib/Core/Executor.cpp
index 6891dc93..2f806aad 100644
--- a/lib/Core/Executor.cpp
+++ b/lib/Core/Executor.cpp
@@ -365,10 +365,10 @@ cl::opt<double> MaxStaticCPSolvePct(
              "instructions (default=1.0 (always))"),
     cl::cat(TerminationCat));
 
-cl::opt<std::string> MaxStaticPctCheckDelay(
+cl::opt<unsigned> MaxStaticPctCheckDelay(
     "max-static-pct-check-delay",
-    cl::desc("Time after which the --max-static-*-pct checks are enforced (default=60s)"),
-    cl::init("60s"),
+    cl::desc("Number of forks after which the --max-static-*-pct checks are enforced (default=1000)"),
+    cl::init(1000),
     cl::cat(TerminationCat));
 
 cl::opt<std::string> TimerInterval(
@@ -491,8 +491,6 @@ Executor::Executor(LLVMContext &ctx, const InterpreterOptions &opts,
   this->solver = new TimingSolver(solver, EqualitySubstitution);
   memory = new MemoryManager(&arrayCache);
 
-  maxStaticPctCheckDelay = time::Span{MaxStaticPctCheckDelay};
-
   initializeSearchOptions();
 
   if (OnlyOutputStatesCoveringNew && !StatsTracker::useIStats())
@@ -979,9 +977,9 @@ ref<Expr> Executor::maxStaticPctChecks(ExecutionState &current,
       MaxStaticCPForkPct == 1. && MaxStaticCPSolvePct == 1.)
     return condition;
 
-  // these checks are performed only after MaxStaticPctCheckDelay time has
-  // passed since execution started
-  if (statsTracker->elapsed() <= maxStaticPctCheckDelay)
+  // These checks are performed only after at least MaxStaticPctCheckDelay forks
+  // have been performed since execution started
+  if (stats::forks < MaxStaticPctCheckDelay)
     return condition;
 
   StatisticManager &sm = *theStatisticManager;